AWS
===

This workspace contains the basic tasks for provisioning and teardown of aws clusters

aws-ec2-new
==========
Provisions a new aws ec2 instance.  Does not generate an inventory

aws-ec2-key-new
===============
Generates a new ec2 keypair

aws-sg-new
==========
Creates a new aws security group

aws-s3-new
==========
Creates a net aws s3 bucket
